pub struct GroupKey { /* private fields */ }Expand description
Group Key is used to join a group and authorize membership.
Notes:
-
Currently only secret-based authentication is implemented.
-
Group Id is derived by hashing the secret bytes with the group configuration and the state machine identifier. See
GroupIdfor more details on how the group id is derived. -
During handshake, peers prove knowledge of the secret without revealing the secret itself by generating a proof of knowledge derived from the secret and the shared random value for the link.
Implementations
Sourceimpl GroupKey
impl GroupKey
Sourcepub fn from_secret(secret: impl Into<Digest>) -> Self
pub fn from_secret(secret: impl Into<Digest>) -> Self
Create a new GroupKey from the given secret UniqueId.
Sourcepub const fn secret(&self) -> &Digest
pub const fn secret(&self) -> &Digest
Gets the underlying secret UniqueId.
This should never be transmitted over the network, only proofs of knowledge should be sent.