Groups

Struct Groups 

pub struct Groups { /* private fields */ }
Public API gateway for the Groups subsystem.

This type is instantiated once per Network instance and is used to join groups and manage them.

Implementations

Source

impl Groups

Public API

pub fn with_key(&self, key: impl Into<GroupKey>) -> GroupBuilder<'_>

Returns a builder for configuring and joining a group with the specified group key.

The group id that will be generated by the builder and joined will be derived according to the rules described in the GroupId type definition. All members of the group must use identical configuration values for all the consensus-relevant parameters, otherwise they will generate different group ids and will not be able to form a bond connection with each other.