Network

Struct Network 

pub struct Network { /* private fields */ }
The entrypoint to the Mosaic network SDK.

Notes:

  • This type represents a Mosaik network connection and provides methods to access different facilities such as peer discovery and stream management.

  • In most cases one network instance will represent one running process/node.

  • Each network instance has a globally unique identity that is the public key of the secret key used to construct it. If no secret key is provided a new random key will be generated. This is an important property because node identities are globally unique across all Mosaik networks and nodes can be addressed by their public keys alone. The discovery mechanism is responsible for resolving the corresponding network addresses for a given public key. Knowing the physical transport addresses of a peer is not sufficient to identify a node and connect to it.

  • By default a random local port will be chosen for the network instance. This can be overridden by providing a specific port in the builder.

  • Mosaik networks are identified by a NetworkId which is a unique identifier (a blake3 hash of the network string name). Nodes can only connect to other nodes that are part of the same network (i.e. have the same NetworkId).

Implementations

Source

impl Network

Public construction API

pub fn builder(network_id: impl Into<NetworkId>) -> NetworkBuilder

Creates a new network builder with a given network id.

pub async fn new(network_id: impl Into<NetworkId>) -> Result<Self, NetworkError>

Creates and returns a new Network instance with the given network ID and default settings.

Source

impl Network

Public API

pub fn network_id(&self) -> &NetworkId

Returns the network identifier of the network that this instance is connected to.

pub const fn local(&self) -> &LocalNode

Returns a reference to the local node instance.

pub async fn online(&self)

Returns a future that resolves when the local node is considered to be online and ready to interact with other peers.

pub const fn discovery(&self) -> &Discovery

Returns a reference to the discovery system.

pub const fn streams(&self) -> &Streams

Returns a reference to the streams system.

pub const fn groups(&self) -> &Groups

Returns a reference to the groups system.