GroupKey

Struct GroupKey 

pub struct GroupKey { /* private fields */ }
Group Key is used to join a group and authorize membership.

Notes:

  • Currently only secret-based authentication is implemented.

  • Group Id is derived by hashing the secret bytes with the group configuration and the state machine identifier. See GroupId for more details on how the group id is derived.

  • During handshake, peers prove knowledge of the secret without revealing the secret itself by generating a proof of knowledge derived from the secret and the shared random value for the link.

Implementations

Source

impl GroupKey

pub const fn new(secret: Digest) -> Self

Creates a new GroupKey from the given secret Digest.

pub fn from_secret(secret: impl Into<Digest>) -> Self

Create a new GroupKey from the given secret UniqueId.

pub fn random() -> Self

Creates a new GroupKey with a randomly generated secret.

pub const fn secret(&self) -> &Digest

Gets the underlying secret UniqueId.

This should never be transmitted over the network, only proofs of knowledge should be sent.

pub fn validate_proof( &self, link: &Link<Groups>, proof: Digest, group_id: GroupId, ) -> bool

Validates the validity of the authentication proof contained in this handshake message against the provided group key and link.

pub fn generate_proof( &self, link: &Link<Groups>, peer_id: PeerId, group_id: GroupId, ) -> Digest

Generates a proof of knowledge of the secret key for the given peer and link.